"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useScrollbarEffects;
var _react = require("react");
var _reactNative = require("react-native");
const computeScrollbarWidth = () => {
  const documentWidth = document.documentElement.clientWidth;
  return Math.abs(window.innerWidth - documentWidth);
};
function useScrollbarEffects(elements) {
  if (_reactNative.Platform.OS !== 'web') {
    return (0, _react.useMemo)(() => ({
      hide() {},
      show() {}
    }), []);
  }
  const state = (0, _react.useRef)({
    counter: 0,
    elements: [],
    originalWidths: [],
    originalBodyOverflow: ''
  });
  return (0, _react.useMemo)(() => ({
    hide() {
      state.current.counter += 1;
      if (state.current.counter !== 1) {
        return;
      }
      const rect = document.body.getBoundingClientRect();
      const isBodyOverflowing = rect.left + rect.right < window.innerWidth;

      // Set body and fixed elements padding adjustments.
      const fixedElements = elements.filter(ref => ref.current).map(ref => (0, _reactNative.findNodeHandle)(ref.current));
      state.current.elements = [document.body, ...fixedElements];
      state.current.originalWidths = state.current.elements.map(el => el.style.width || '');
      state.current.originalBodyOverflow = document.body.style.overflow || '';
      if (isBodyOverflowing) {
        const scrollbarWidth = computeScrollbarWidth();
        state.current.elements.forEach(el => {
          // eslint-disable-next-line no-param-reassign
          el.style.width = `calc(100% - ${scrollbarWidth}px)`;
        });
      }

      // Add "overflow: hidden" to body element.
      document.body.style.overflow = 'hidden';
    },
    show() {
      state.current.counter -= 1;
      if (state.current.counter !== 0) {
        return;
      }

      // Remove "overflow: hidden" from body element.
      document.body.style.overflow = state.current.originalBodyOverflow;

      // Reset body padding adjustments.
      state.current.elements.forEach((el, key) => {
        // eslint-disable-next-line no-param-reassign
        el.style.width = state.current.originalWidths[key] || '';
      });
    }
  }), []);
}
//# sourceMappingURL=useScrollbarEffects.js.map